.. highlight:: shell

============
Installation
============


Stable release
--------------

To install peek, run this command in your terminal:

.. code-block:: console

    $ pip install es-peek

This is the preferred method to install peek, as it will always install the most recent stable release.
The above installation does not include support of Kerberos and system clipboard. To get these two
features, please install the full package:

.. code-block:: console

    $ pip install es-peek[full]

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for peek can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/ywangd/peek

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/ywangd/peek/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/ywangd/peek
.. _tarball: https://github.com/ywangd/peek/tarball/master
